@@ -1,7 +1,7 @@
 # ABSTRACT: Model a news article in the NewsReach API
 package WWW::NewsReach::NewsItem;
 
-our $VERSION = '0.05';
+our $VERSION = '0.06';
 
 use Moose;
 
@@ -22,7 +22,7 @@ has $_ => (
 has $_ => (
     is  => 'ro',
     isa => 'DateTime',
-) for qw(publishDate lastModifiedDate publishTime);
+) for qw(publishDate lastModifiedDate);
 
 has id => (
     is  => 'ro',
@@ -63,7 +63,6 @@ sub new_from_xml {
         my $dt_str    = $xml->findnodes("//$_")->[0]->textContent;
         my $dt        = $iso8601->parse_datetime( $dt_str );
         $self->{$_} = $dt;
-        eval { $self->{publishTime} = $dt->hms; }; # time is optional
     }
 
     my $photo_xml = $class->_get_related_xml( $xml, 'photos' );
@@ -111,7 +110,7 @@ WWW::NewsReach::NewsItem - Model a news article in the NewsReach API
 
 =head1 VERSION
 
-version 0.05
+version 0.06
 
 =head1 METHODS
 
